PySkein 0.7.1 - The Skein Hash Algorithm for Python — PySkein v0.7.1 documentation

### Navigation

- index
- next |
- PySkein v0.7.1 documentation »

# PySkein 0.7.1 - The Skein Hash Algorithm for Python

PySkein is an extension module for Python, implementing the Skein hash algorithm, one of the finalists in the NIST SHA-3 Competition. While originally based on the optimized version of the reference implementation by Doug Whiting, PySkein is now feature complete and offers a pythonic interface, all released as free software under the GNU General Public License. Its highlights are:

- Simple interface following the hash algorithms in the Python standard library (like hashlib.sha1 or hashlib.sha256)
- All features of the Skein specification (flexible digest sizes, MAC generation, tree hashing, and various other arguments)
- High performance through optimized C implementation (7.1 cycles/byte for sequential hashing and 4.2 cycles/byte for tree hashing on two cores, measured on an Athlon 64 X2)
- Threefish, the tweakable block cipher used in Skein, available for encryption and decryption on its own

Table of Contents:

- Skein hash
  - Hash objects
  - Examples of simple hashing
  - Examples of input parameter usage
  - Tree hashing
- Threefish block cipher
  - Threefish objects
  - Examples
- Pseudorandom Number Generator
- Skein Stream Cipher
- Demo Scripts
  - skeinsum
  - threefish
- Download PySkein
  - Skein versions
  - Changes between version
  - Previous versions

### Navigation

- index
- next |
- PySkein v0.7.1 documentation »